@@ -6,5 +6,5 @@ package readline
 import "errors"
 
 func (rl *Instance) launchEditor(multiline []rune) ([]rune, error) {
-	return rl.line, errors.New("Not currently supported on Plan 9")
+	return rl.line.Runes(), errors.New("Not currently supported on Plan 9")
 }
